@@ -5,7 +5,7 @@ import torch
 from torch import nn
 from torch.optim import SGD
 from torchero.base import BatchTrainer, BatchValidator
-from torchero.callbacks import Callback, History, CSVLogger, ModelCheckpoint, MeterNotFound, EarlyStopping
+from torchero.callbacks import Callback, History, CSVLogger, ModelCheckpoint, MeterNotFound, EarlyStopping, ProgbarLogger
 from torchero import meters
 from torchero.meters import Averager, MSE, RMSE, CategoricalAccuracy
 from torch.utils.data import DataLoader, TensorDataset
@@ -27,6 +27,16 @@ class DummyModel(nn.Module):
     def forward(self, x):
         return x
 
+class BinaryNetwork(nn.Module):
+    def __init__(self):
+        super(BinaryNetwork, self).__init__()
+        self.linear = nn.Linear(2, 1)
+
+    def forward(self, x):
+        x = self.linear(x)
+        x = x.view(-1)
+        return x
+
 class TestValidator(BatchValidator):
     def __init__(self, model, meters, trainer=None):
         super(TestValidator, self).__init__(model, meters)
@@ -37,8 +47,8 @@ class TestValidator(BatchValidator):
             self.trainer.valid_batch_fn(self, *args, **kwargs)
 
 class TestTrainer(BatchTrainer):
-    def create_validator(self):
-        return TestValidator(self.model, self.val_meters, self)
+    def create_validator(self, meters):
+        return TestValidator(self.model, meters, self)
 
     def __init__(self, *args, **kwargs):
         self.update_batch_fn = None
